Name: ssh
Summary: Secure Shell environment
%define version 2.0.13
Version: %{version}
Release: 1b
Source0: ftp://ftp.cs.hut.fi/pub/ssh/ssh-%{version}.tar.gz
Source1: sshd.init
Source2: sshd.init.hp
Source3: sshd.rc.hp
Patch0: ssh-%{version}-ppc.patch
Patch1: ssh-%{version}-sftp_hash.patch
NoSource: 0
Copyright: (C) 1995-1999 SSH Communications Security Ltd., Finland
URL:	<http://www.ssh.fi>
Group: Shells
BuildRoot: /tmp/ssh-root
%ifarch hppa1.1
%define prefix /jlc/local
%define perlbin %{prefix}/perl5/bin
#%define etcdir %{prefix}/etc
%define etcdir /etc
%else
%define prefix /usr
%define perlbin %{prefix}/bin
%define etcdir /etc
%endif

%description
Ssh (Secure Shell) is a program to log into another computer over a network, to execute commands in a remote
machine, and to move files from one machine to another. It provides strong authentication and secure
communications over insecure channels. Its features include the following: 

    Strong authentication. Closes several security holes (e.g., IP, routing, DNS spoofing, and listening for
    passwords from the network). New authentication methods: .rhosts together with RSA based host
    authentication, and pure RSA authentication. 

    All communications are automatically and transparently encrypted. Encryption is also used to protect against
    spoofed packets and hijacked connections. 

    X11 connection forwarding provides secure X11 sessions. 

    Arbitrary TCP/IP ports can be redirected over the encrypted channel in both directions. 

    Client RSA-authenticates the server machine in the beginning of every connection to prevent trojan horses 
    (by routing or DNS spoofing) and man-in-the-middle attacks. The server RSA-authenticates the client machine
    before accepting .rhosts or %{etcdir}/hosts.equiv authentication (to prevent DNS, routing, or IP spoofing). 

    An authentication agent, running in the user's local workstation or laptop, can be used to hold the user's
    RSA authentication keys. 

    Multiple convenience features fix annoying problems with rlogin and rsh. 

Ssh is intended as a complete replacement for rlogin, rsh, rcp, and rdist. It can also replace telnet 
in many cases. 

%package default
Summary: Files and symbolic links to make this the default ssh
Group: Shells
%description default
This package contains symbolic links for "s" commands and 
their corresponding "man" pages. It also provides an automatic
startup mechanism for sshd.


%prep
%setup -n ssh-%{version}
%ifarch ppc
%patch0 -p1
%endif
%patch1 -p1

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{prefix}/{bin,sbin}
mkdir -p $RPM_BUILD_ROOT%{prefix}/man/{man1,man8}
%ifnarch hppa1.1
mkdir -p $RPM_BUILD_ROOT%{etcdir}/rc.d/{init.d,rc6.d,rc3.d,rc1.d,rc0.d}
mkdir -p $RPM_BUILD_ROOT%{etcdir}/rc.d/{rc2.d,rc4.d,rc5.d}
%else
mkdir -p $RPM_BUILD_ROOT/etc/rc.config.d
mkdir -p $RPM_BUILD_ROOT/sbin/{init.d,rc1.d,rc2.d}
%endif

%build
env PERL='%{perlbin}/perl' CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix=%{prefix} \
		--with-etcdir=%{etcdir}
make

%install
make install DESTDIR=$RPM_BUILD_ROOT
%ifnarch hppa1.1
cp $RPM_SOURCE_DIR/sshd.init $RPM_BUILD_ROOT%{etcdir}/rc.d/init.d/sshd
chmod +x $RPM_BUILD_ROOT%{etcdir}/rc.d/init.d/sshd
ln -sf ../init.d/sshd $RPM_BUILD_ROOT%{etcdir}/rc.d/rc6.d/K14sshd
ln -sf ../init.d/sshd $RPM_BUILD_ROOT%{etcdir}/rc.d/rc2.d/S86sshd
ln -sf ../init.d/sshd $RPM_BUILD_ROOT%{etcdir}/rc.d/rc3.d/S86sshd
ln -sf ../init.d/sshd $RPM_BUILD_ROOT%{etcdir}/rc.d/rc4.d/S86sshd
ln -sf ../init.d/sshd $RPM_BUILD_ROOT%{etcdir}/rc.d/rc5.d/S86sshd
ln -sf ../init.d/sshd $RPM_BUILD_ROOT%{etcdir}/rc.d/rc1.d/K14sshd
ln -sf ../init.d/sshd $RPM_BUILD_ROOT%{etcdir}/rc.d/rc0.d/K14sshd
%else
cp $RPM_SOURCE_DIR/sshd.rc.hp $RPM_BUILD_ROOT/etc/rc.config.d/sshd
cp $RPM_SOURCE_DIR/sshd.init.hp $RPM_BUILD_ROOT/sbin/init.d/sshd
chmod +x $RPM_BUILD_ROOT/sbin/init.d/sshd
ln -sf ../init.d/sshd $RPM_BUILD_ROOT/sbin/rc1.d/K080sshd
ln -sf ../init.d/sshd $RPM_BUILD_ROOT/sbin/rc2.d/S920sshd
%endif
ln -sf ssh2 $RPM_BUILD_ROOT%{prefix}/bin/slogin

%clean
rm -rf $RPM_BUILD_ROOT

%files
%doc LICENSING README CHANGES BUG.REPORT FAQ SSH2.QUICKSTART
%dir	%{etcdir}/ssh2
%config %{etcdir}/ssh2/ssh2_config
%config %{etcdir}/ssh2/sshd2_config
#%{etcdir}/ssh2/hostkey
#%{etcdir}/ssh2/hostkey.pub
%{prefix}/bin/scp2
%{prefix}/bin/sftp-server2
%{prefix}/bin/sftp2
%{prefix}/bin/ssh-add2
%{prefix}/bin/ssh-agent2
%{prefix}/bin/ssh-askpass2
%{prefix}/bin/ssh-keygen2
%{prefix}/bin/ssh-signer2
%{prefix}/bin/ssh2
%{prefix}/sbin/sshd2
%{prefix}/man/man1/scp2.1
%{prefix}/man/man1/sftp2.1
%{prefix}/man/man1/ssh-add2.1
%{prefix}/man/man1/ssh-agent2.1
%{prefix}/man/man1/ssh-keygen2.1
%{prefix}/man/man1/ssh2.1
%{prefix}/man/man8/sshd2.8

%files default
%ifnarch hppa1.1
%config %{etcdir}/rc.d/init.d/sshd
%{etcdir}/rc.d/rc0.d/K14sshd
%{etcdir}/rc.d/rc1.d/K14sshd
%{etcdir}/rc.d/rc2.d/S86sshd
%{etcdir}/rc.d/rc3.d/S86sshd
%{etcdir}/rc.d/rc4.d/S86sshd
%{etcdir}/rc.d/rc5.d/S86sshd
%{etcdir}/rc.d/rc6.d/K14sshd
%else
%config /etc/rc.config.d/sshd
/sbin/init.d/sshd
/sbin/rc1.d/K080sshd
/sbin/rc2.d/S920sshd
%endif
%{prefix}/bin/scp
%{prefix}/bin/sftp
%{prefix}/bin/sftp-server
%{prefix}/bin/slogin
%{prefix}/bin/ssh
%{prefix}/bin/ssh-add
%{prefix}/bin/ssh-agent
%{prefix}/bin/ssh-askpass
%{prefix}/bin/ssh-keygen
%{prefix}/bin/ssh-signer
%{prefix}/sbin/sshd
%{prefix}/man/man1/scp.1
%{prefix}/man/man1/sftp.1
%{prefix}/man/man1/ssh-add.1
%{prefix}/man/man1/ssh-agent.1
%{prefix}/man/man1/ssh-keygen.1
%{prefix}/man/man1/ssh.1
%{prefix}/man/man8/sshd.8

%changelog
* Sat Jun 12 1999 Keisuke Fujii <fujiik@jlcuxf.kek.jp>
- Updated init script and its symbolic links

* Wed May 26 1999 Keisuke Fujii <fujiik@jlcuxf.kek.jp>
- Version 2.0.13
- Removed hostkey and hostkey.pub from the package
- Added ssh-signer*
- Added a sftp_hash patch

* Sun Feb 28 1999 Keisuke Fujii <fujiik@jlcuxf.kek.jp>
- Version 2.0.12

* Sun Jan 10 1999 Keisuke Fujii <fujiik@jlcuxf.kek.jp>
- Version 2.0.11

* Sat Oct 30 1998 Keisuke Fujii <fujiik@jlcuxf.kek.jp>
- Version 2.0.10

* Sat Sep 26 1998 Keisuke Fujii <fujiik@jlcuxf.kek.jp>
- Version 2.0.9

* Tue Sep 3 1998 Keisuke Fujii <fujiik@jlcuxf.kek.jp>
- Added a ppc patch

* Tue Sep 1 1998 Keisuke Fujii <fujiik@jlcuxf.kek.jp>
- Version 2.0.8

* Wed Jul 15 1998 Keisuke Fujii <fujiik@jlcuxf.kek.jp>
- Version 1.2.26

* Fri Jun 20 1998 Keisuke Fujii <fujiik@jlcuxf.kek.jp>
- Version 1.2.22

* Fri Oct 17 1997 Gary Thomas <g.thomas@opengroup.org>
- Fix typo in "sshd.init".
